==> smb_scheduler_install-v1.5.tar.gz: smb_scheduler_install/smb_scheduler/api.php <==
<?php 
define("OK", true);
require_once("global.php");
if(!get_magic_quotes_gpc()){
	$_REQUEST[username]=addslashes($_REQUEST[username]);
	$_REQUEST[password]=addslashes($_REQUEST[password]);
}

if(!isset($_SESSION['usertype'])){
	$rs=$db->fetch_array($db->query("SELECT id FROM user WHERE name='".$_REQUEST[username]."' and password='".md5(md5($_REQUEST[password].'dbl').'yzm')."'"));
	if(empty($rs[0])){
                require_once ('login.php');
                exit;
        }
}else {
	require_once ('login.php');
	exit;
}


if($_REQUEST['get']=='sim_line'){
	$query=$db->query("select sim_name from sim");
	echo "sim name:\n";
	while($row=@$db->fetch_array($query)) {
		echo "$row[0]\n";
	}
	$query=$db->query("select line_name from device_line");

	echo "line name:\n";
	while($row=@$db->fetch_array($query)) {
		echo "$row[0]\n";
	}
}
elseif($_REQUEST['get']=='sim'){
        $query=$db->query("select sim_name from sim");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0]\n";
        }
}
elseif($_REQUEST['get']=='line'){
        $query=$db->query("select line_name from device_line");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0]\n";
        }
}
elseif($_REQUEST['get']=='bind'){
	if($_REQUEST[sim]) $where=" and sim_name=$_REQUEST[sim]";
	if($_REQUEST[line]) $where=" and line_name=$_REQUEST[line]";
	$query=$db->query("select sim_name,line_name from sim where line_name != '' $where");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0] $row[1];\n";
        }
}
elseif($_REQUEST['get']=='plan_bind'){
	if($_REQUEST[sim]) $where=" and sim_name=$_REQUEST[sim]";
	if($_REQUEST[line]) $where=" and plan_line_name=$_REQUEST[line]";
        $query=$db->query("select sim_name,plan_line_name from sim where plan_line_name != '' $where");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0] $row[1];\n";
        }
}
elseif($_REQUEST['set']=='bind'){
	$rs_sim=$db->fetch_array($db->query("select * from sim where sim_name='$_REQUEST[sim]'"));
	$rs_line=$db->fetch_array($db->query("select * from device_line where line_name='$_REQUEST[line]'"));
	if(empty($rs_sim[0])){
		echo "ERROR sim_name error!";
		exit;
	}
	if(empty($rs_line[0]) && $_REQUEST[line]!=0){
		echo "ERROR line_name error!";
		exit;
	}
	$rs=$db->fetch_array($db->query("select * from sim where plan_line_name='$_REQUEST[line]'"));
	if($rs[0]){
		$send[]=my_pack2(DEV_BINDING, $rs[sim_name], 0);
		$db->query("update sim set plan_line_name='' where plan_line_name='$_REQUEST[line]'");
	}
	$db->query("update sim set plan_line_name='$_REQUEST[line]' where sim_name='$_REQUEST[sim]'");
        $send[]=my_pack2(DEV_BINDING, $_REQUEST[sim], $_REQUEST[line]);
	echo "OK.bind sim:$_REQUEST[sim]; line:$_REQUEST[line]";
        sendto_xchanged($send);
}
elseif($_REQUEST['set']=='imei'){
	if(!$_REQUEST[imei]) {
		echo "ERROR imei error!";
		exit;
	}
	if($_REQUEST[sim]) {
		$rs=$db->fetch_array($db->query("select * from sim where sim_name='$_REQUEST[sim]'"));
		if(empty($rs[0])){
			echo "ERROR sim_name error!";
			exit;
		}
	}
	else if($_REQUEST[line]){
		$rs=$db->fetch_array($db->query("select * from sim where line_name='$_REQUEST[line]'"));
		if(empty($rs[0])){
			echo "ERROR this line not bind sim!";
			exit;
                }
	}
	else {
		echo "ERROR sim_name and line_name none!";
		exit;
	}
	$db->query("update sim set imei_mode='2', imei='$_REQUEST[imei]' where sim_name='$rs[sim_name]'");
	$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$_REQUEST[sim]'");
	if($row=$db->fetch_array($query)) {
		if($row['imei']==NULL) $row['imei'] = "000000000000000";
		$imei_len=strlen($row['imei']);
		if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
		if($row['remain_time']==NULL || $row['remain_time'] <-1 ) $row['remain_time'] = -1;
		$send[]=my_pack($row, SIM_ADD);
		if($row['line_name']) $send[]=my_pack2(MODULE_REBOOT, $row['line_name']);
		sendto_xchanged($send);
		echo "OK";
	}
	else echo "ERROR sim_name error!";
}

?>

==> smb_scheduler_install-v1.6.tar.gz: smb_scheduler_install/smb_scheduler/api.php <==
<?php 
define("OK", true);
require_once("global.php");

foreach($_REQUEST as $key => $value) 
{
	$_REQUEST[$key]=myaddslashes($value);
}
/*
if(!get_magic_quotes_gpc()){
	$_REQUEST[username]=addslashes($_REQUEST[username]);
	$_REQUEST[password]=addslashes($_REQUEST[password]);
}
*/

if(!isset($_SESSION['usertype'])){
	$rs=$db->fetch_array($db->query("SELECT id FROM user WHERE name='".$_REQUEST[username]."' and password='".md5(md5($_REQUEST[password].'dbl').'yzm')."'"));
	if(empty($rs[0])){
                require_once ('login.php');
                exit;
        }
}else {
	require_once ('login.php');
	exit;
}

if($_REQUEST['get']=='sim_line'){
	$query=$db->query("select sim_name from sim");
	echo "sim name:\n";
	while($row=@$db->fetch_array($query)) {
		echo "$row[0]\n";
	}
	$query=$db->query("select line_name from device_line");

	echo "line name:\n";
	while($row=@$db->fetch_array($query)) {
		echo "$row[0]\n";
	}
}
elseif($_REQUEST['get']=='sim'){
        $query=$db->query("select sim_name from sim");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0]\n";
        }
}
elseif($_REQUEST['get']=='line'){
        $query=$db->query("select line_name from device_line");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0]\n";
        }
}
elseif($_REQUEST['get']=='bind'){
	if($_REQUEST[sim]) $where=" and sim_name=$_REQUEST[sim]";
	if($_REQUEST[line]) $where=" and line_name=$_REQUEST[line]";
	$query=$db->query("select sim_name,line_name from sim where line_name != '' $where");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0] $row[1];\n";
        }
}
elseif($_REQUEST['get']=='plan_bind'){
	if($_REQUEST[sim]) $where=" and sim_name=$_REQUEST[sim]";
	if($_REQUEST[line]) $where=" and plan_line_name=$_REQUEST[line]";
        $query=$db->query("select sim_name,plan_line_name from sim where plan_line_name != '' $where");
        while($row=@$db->fetch_array($query)) {
                echo "$row[0] $row[1];\n";
        }
}
elseif($_REQUEST['set']=='bind'){
	$rs_sim=$db->fetch_array($db->query("select * from sim where sim_name='$_REQUEST[sim]'"));
	$rs_line=$db->fetch_array($db->query("select * from device_line where line_name='$_REQUEST[line]'"));
	if(empty($rs_sim[0])){
		echo "ERROR sim_name error!";
		exit;
	}
	if(empty($rs_line[0]) && $_REQUEST[line]!=0){
		echo "ERROR line_name error!";
		exit;
	}
	$rs=$db->fetch_array($db->query("select * from sim where plan_line_name='$_REQUEST[line]'"));
	if($rs[0]){
		$send[]=my_pack2(DEV_BINDING, $rs[sim_name], 0);
		$db->query("update sim set plan_line_name='' where plan_line_name='$_REQUEST[line]'");
	}
	$db->query("update sim set plan_line_name='$_REQUEST[line]' where sim_name='$_REQUEST[sim]'");
        $send[]=my_pack2(DEV_BINDING, $_REQUEST[sim], $_REQUEST[line]);
	echo "OK.bind sim:$_REQUEST[sim]; line:$_REQUEST[line]";
        sendto_xchanged($send);
}
elseif($_REQUEST['set']=='disable' ||$_REQUEST['set']=='enable'){
	
	if($_REQUEST[sim]) {
		$query=$db->query("select id from sim where sim_name='$_REQUEST[sim]'");
		if($row=$db->fetch_array($query)){
			if($_REQUEST['set']=='disable') $db->query("update sim set dev_disable=1 where sim_name='$_REQUEST[sim]'");
			else $db->query("update sim set dev_disable=0 where sim_name='$_REQUEST[sim]'");
			$send[]=my_pack2(($_REQUEST['set']=='disable')?DEV_DISABLE:DEV_ENABLE, $_REQUEST[sim], TYPE_SIM);
			sendto_xchanged($send);
			echo "OK";
		}
		else echo "ERROR sim_name error!";
	}
	if($_REQUEST[line]) {
		$query=$db->query("select id from device_line where line_name='$_REQUEST[line]'");
		if($row=$db->fetch_array($query)){
			if($_REQUEST['set']=='disable') $db->query("update device_line set dev_disable=1 where line_name='$_REQUEST[line]'");
			else $db->query("update device_line set dev_disable=0 where line_name='$_REQUEST[line]'");
			$send[]=my_pack2(($_REQUEST['set']=='disable')?DEV_DISABLE:DEV_ENABLE, $_REQUEST[line], TYPE_GOIP);
			sendto_xchanged($send);
			echo "OK";
		}
		else echo "ERROR line_name error!";
	}
}

elseif($_REQUEST['set']=='imei'){
	if(!$_REQUEST[imei]) {
		echo "ERROR imei error!";
		exit;
	}
	if($_REQUEST[sim]) {
		$rs=$db->fetch_array($db->query("select * from sim where sim_name='$_REQUEST[sim]'"));
		if(empty($rs[0])){
			echo "ERROR sim_name error!";
			exit;
		}
	}
	else if($_REQUEST[line]){
		$rs=$db->fetch_array($db->query("select * from sim where line_name='$_REQUEST[line]'"));
		if(empty($rs[0])){
			echo "ERROR this line not bind sim!";
			exit;
                }
	}
	else {
		echo "ERROR sim_name and line_name none!";
		exit;
	}
	$db->query("update sim set imei_mode='2', imei='$_REQUEST[imei]' where sim_name='$rs[sim_name]'");
	$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$_REQUEST[sim]'");
	if($row=$db->fetch_array($query)) {
		if($row['imei']==NULL) $row['imei'] = "000000000000000";
		$imei_len=strlen($row['imei']);
		if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
		if($row['remain_time']==NULL || $row['remain_time'] <-1 ) $row['remain_time'] = -1;
		$send[]=my_pack($row, SIM_ADD);
		if($row['line_name']) $send[]=my_pack2(MODULE_REBOOT, $row['line_name']);
		sendto_xchanged($send);
		echo "OK";
	}
	else echo "ERROR sim_name error!";
}

?>
